import { Component, ChangeDetectionStrategy, signal, computed } from '@angular/core';
import { ProductSelectionComponent, Product } from '../product-selection/product-selection.component';
import { ProductQuantityComponent } from '../product-quantity/product-quantity.component';
import { CurrencyPipe } from '@angular/common';
@Component({
  selector: 'app-product-overview',
  standalone: true,
  imports: [ProductSelectionComponent, ProductQuantityComponent, CurrencyPipe],
  templateUrl: './product-overview.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class ProductOverviewComponent {
  selectedProduct = signal<Product | null>(null);
  quantity = signal<number>(1);
  
  total = computed(() => {
    const product = this.selectedProduct();
    return product ? product.price * this.quantity() : 0;
  });

  onProductChange(product: Product) {
    this.selectedProduct.set(product);
  }

  onQuantityChange(quantity: number) {
    this.quantity.set(quantity);
  }
}
