import { NgFor, NgIf } from '@angular/common';
import { CurrencyPipe } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { Component, ChangeDetectionStrategy, Output, EventEmitter, signal, inject, computed, OnInit } from '@angular/core';
import { ProductService } from '../services/product.service';

export type Product = {
  id: number;
  title: string;
  price: number;
  description: string;
  category: string;
  image: string;
  rating: {
    rate: number;
    count: number;
  }
}

@Component({
  selector: 'app-product-selection',
  standalone: true,
  imports: [NgFor, CurrencyPipe, FormsModule, NgIf],
  templateUrl: './product-selection.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})

export class ProductSelectionComponent implements OnInit {
  products = signal<Product[]>([]);

  selectedProduct = signal<Product | null>(null);

  quantity = signal<number>(1);

  isProductLoading = signal(true);
  
  @Output() quantityChange = new EventEmitter<number>();
  @Output() productChange = new EventEmitter<Product>();

  private productService = inject(ProductService);

  ngOnInit() {
    this.productService.getProducts().subscribe(products => {
      this.products.set(products);
      this.isProductLoading.set(false);
    });
  }

  onProductChange(selectedProduct: Product) {
    this.selectedProduct.set(selectedProduct);
    const product = this.selectedProduct();
    if (product) {
      this.productChange.emit(product);
      this.quantity.set(1);
      this.quantityChange.emit(1);
    }
  }
}
